@@ -6,12 +6,11 @@ import struct
 from .cmapdb import CMapDB, CMapParser, FileUnicodeMap, CMap
 from .encodingdb import EncodingDB, name2unicode
 from .psparser import PSStackParser
-from .psparser import PSSyntaxError, PSEOF
+from .psparser import PSEOF
 from .psparser import LIT, KWD, STRICT
 from .psparser import PSLiteral, literal_name
-from .pdftypes import PDFException, resolve1
-from .pdftypes import int_value, float_value, num_value
-from .pdftypes import str_value, list_value, dict_value, stream_value
+from .pdftypes import (PDFException, resolve1, int_value, num_value, list_value, dict_value,
+    stream_value)
 from .fontmetrics import FONT_METRICS
 from .utils import apply_matrix_norm, nunpack, choplist
 
@@ -61,17 +60,13 @@ def get_widths2(seq):
 #assert get_widths2([1,[2,3,4,5],6,[7,8,9]]) == {1:(2,(3,4)), 6:(7,(8,9))}
 
 
-##  FontMetricsDB
-##
-class FontMetricsDB(object):
+class FontMetricsDB:
 
     @classmethod
     def get_metrics(klass, fontname):
         return FONT_METRICS[fontname]
 
 
-##  Type1FontHeaderParser
-##
 class Type1FontHeaderParser(PSStackParser):
 
     KEYWORD_BEGIN = KWD('begin')
@@ -87,7 +82,6 @@ class Type1FontHeaderParser(PSStackParser):
     def __init__(self, data):
         PSStackParser.__init__(self, data)
         self._cid2unicode = {}
-        return
 
     def get_encoding(self):
         while 1:
@@ -107,7 +101,6 @@ class Type1FontHeaderParser(PSStackParser):
             if (isinstance(key, int) and
                 isinstance(value, PSLiteral)):
                 self.add_results((key, literal_name(value)))
-        return
 
     
 ##  CFFFont
@@ -156,7 +149,7 @@ def getdict(data):
         stack.append(value)
     return d
 
-class CFFFont(object):
+class CFFFont:
 
     STANDARD_STRINGS = (
       '.notdef', 'space', 'exclam', 'quotedbl', 'numbersign',
@@ -239,7 +232,7 @@ class CFFFont(object):
       'Light', 'Medium', 'Regular', 'Roman', 'Semibold',
       )
 
-    class INDEX(object):
+    class INDEX:
 
         def __init__(self, fp):
             self.fp = fp
@@ -249,7 +242,6 @@ class CFFFont(object):
                 self.offsets.append(nunpack(self.fp.read(offsize)))
             self.base = self.fp.tell()-1
             self.fp.seek(self.base+self.offsets[-1])
-            return
 
         def __repr__(self):
             return '<INDEX: size=%d>' % len(self)
@@ -342,7 +334,6 @@ class CFFFont(object):
         #print self.code2gid
         #print self.name2gid
         #assert 0
-        return
 
     def getstr(self, sid):
         if sid < len(self.STANDARD_STRINGS):
@@ -350,9 +341,7 @@ class CFFFont(object):
         return self.string_index[sid-len(self.STANDARD_STRINGS)]
 
 
-##  TrueTypeFont
-##
-class TrueTypeFont(object):
+class TrueTypeFont:
 
     class CMapNotFound(Exception): pass
 
@@ -365,7 +354,6 @@ class TrueTypeFont(object):
         for _ in range(ntables):
             (name, tsum, offset, length) = struct.unpack(b'>4sLLL', fp.read(16))
             self.tables[name] = (offset, length)
-        return
 
     def create_unicode_map(self):
         if 'cmap' not in self.tables:
@@ -439,8 +427,7 @@ LITERAL_STANDARD_ENCODING = LIT('StandardEncoding')
 LITERAL_TYPE1C = LIT('Type1C')
 
 
-# PDFFont
-class PDFFont(object):
+class PDFFont:
 
     def __init__(self, descriptor, widths, default_width=None):
         self.descriptor = descriptor
@@ -456,7 +443,6 @@ class PDFFont(object):
         self.leading = num_value(descriptor.get('Leading', 0))
         self.bbox = list_value(descriptor.get('FontBBox', (0,0,0,0)))
         self.hscale = self.vscale = .001
-        return
 
     def __repr__(self):
         return '<PDFFont>'
@@ -499,7 +485,6 @@ class PDFFont(object):
         return sum( self.char_width(cid) for cid in self.decode(s) )
 
 
-# PDFSimpleFont
 class PDFSimpleFont(PDFFont):
 
     def __init__(self, descriptor, widths, spec):
@@ -522,7 +507,6 @@ class PDFSimpleFont(PDFFont):
             self.unicode_map = FileUnicodeMap()
             CMapParser(self.unicode_map, io.BytesIO(strm.get_data())).run()
         PDFFont.__init__(self, descriptor, widths)
-        return
 
     def to_unichr(self, cid):
         if self.unicode_map:
@@ -535,7 +519,6 @@ class PDFSimpleFont(PDFFont):
         except KeyError:
             raise PDFUnicodeNotDefined(None, cid)
 
-# PDFType1Font
 class PDFType1Font(PDFSimpleFont):
 
     def __init__(self, rsrcmgr, spec):
@@ -561,18 +544,15 @@ class PDFType1Font(PDFSimpleFont):
             data = self.fontfile.get_data()[:length1]
             parser = Type1FontHeaderParser(io.BytesIO(data))
             self.cid2unicode = parser.get_encoding()
-        return
 
     def __repr__(self):
         return '<PDFType1Font: basefont=%r>' % self.basefont
 
-# PDFTrueTypeFont
 class PDFTrueTypeFont(PDFType1Font):
 
     def __repr__(self):
         return '<PDFTrueTypeFont: basefont=%r>' % self.basefont
 
-# PDFType3Font
 class PDFType3Font(PDFSimpleFont):
 
     def __init__(self, rsrcmgr, spec):
@@ -589,13 +569,11 @@ class PDFType3Font(PDFSimpleFont):
         self.matrix = tuple(list_value(spec.get('FontMatrix')))
         (_,self.descent,_,self.ascent) = self.bbox
         (self.hscale,self.vscale) = apply_matrix_norm(self.matrix, (1,1))
-        return
 
     def __repr__(self):
         return '<PDFType3Font>'
 
 
-# PDFCIDFont
 class PDFCIDFont(PDFFont):
 
     def __init__(self, rsrcmgr, spec):
@@ -664,7 +642,6 @@ class PDFCIDFont(PDFFont):
             widths = get_widths(list_value(spec.get('W', [])))
             default_width = spec.get('DW', 1000)
         PDFFont.__init__(self, descriptor, widths, default_width=default_width)
-        return
 
     def __repr__(self):
         return '<PDFCIDFont: basefont=%r, cidcoding=%r>' % (self.basefont, self.cidcoding)
@@ -684,13 +661,13 @@ class PDFCIDFont(PDFFont):
 
     def to_unichr(self, cid):
         try:
-            if not self.unicode_map: raise KeyError(cid)
+            if not self.unicode_map:
+                raise KeyError(cid)
             return self.unicode_map.get_unichr(cid)
         except KeyError:
             raise PDFUnicodeNotDefined(self.cidcoding, cid)
 
 
-# main
 def main(argv):
     for fname in argv[1:]:
         fp = io.open(fname, 'rb')
@@ -698,6 +675,6 @@ def main(argv):
         font = CFFFont(fname, fp)
         print(font)
         fp.close()
-    return
 
-if __name__ == '__main__': sys.exit(main(sys.argv))
+if __name__ == '__main__':
+    sys.exit(main(sys.argv))
